@@ -2,7 +2,7 @@ package Test::Ika;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Module::Load;
 use Test::Name::FromLine;
@@ -14,6 +14,7 @@ use parent qw/Exporter/;
 
 our @EXPORT = (qw(
     describe it context
+    before_suite after_suite
     before_all after_all before_each after_each
     runtests
 ));
@@ -67,6 +68,16 @@ sub it {
     $CURRENT->add_example($it);
 }
 
+sub before_suite(&) {
+    my $code = shift;
+    $ROOT->add_trigger(before_all => $code);
+}
+
+sub after_suite(&) {
+    my $code = shift;
+    $ROOT->add_trigger(after_all => $code);
+}
+
 sub before_all(&) {
     my $code = shift;
     $CURRENT->add_trigger(before_all => $code);
@@ -201,6 +212,10 @@ It's alias of 'describe' function.
 
 Create new L<Test::Ika::Example>.
 
+=item before_suite(\&code)
+
+Register hook.
+
 =item before_all(\&code)
 
 Register hook.
@@ -209,6 +224,10 @@ Register hook.
 
 Register hook.
 
+=item after_suite(\&code)
+
+Register hook.
+
 =item after_all(\&code)
 
 Register hook.
